# hebireki (蛇暦)
![GitHub tag (latest SemVer)](https://img.shields.io/github/tag/akiyamn/hebireki.svg)&nbsp;
[![PyPI](https://img.shields.io/pypi/v/hebireki.svg)](https://pypi.org/project/hebireki)&nbsp;
![GitHub last commit](https://img.shields.io/github/last-commit/akiyamn/hebireki.svg)&nbsp;
![GitHub](https://img.shields.io/github/license/akiyamn/hebireki.svg)&nbsp;

A lightweight wrapper around Python's inbuilt datetime package, implementing traditional Japanese calendar date and time formatting.

This package is Reiwa safe and is built with extensibility and simplicity in mind.

Hosted at: [https://github.com/akiyamn/hebireki](https://github.com/akiyamn/hebireki)

Hosted at: [https://github.com/akiyamn/hebireki](https://github.com/akiyamn/hebireki)
